<?php 
	// --------------------------
	// Simple PHP Blog Theme File
	// --------------------------
	//
	// Name: Classic Theme
	// Author: Alexander Palmo
	// Version: 0.3.7.1
	//
	// Description:
	// This the is default theme for Simple PHP Blog. You can use
	// this as a template for your own themes.
	//
	// All graphic will be relative to the base-url (i.e. the folder
	// where index.php is located.) 
	
	theme_init();
	
	// ---------------
	// Theme Variables
	// ---------------
	function theme_init () {
		global $theme_vars;
		
		$theme_vars = array();
		$theme_vars['popup_window']['width'] = 550;
		$theme_vars['popup_window']['height'] = 600;
		
		$theme_vars['menu_width'] = 240;
		$theme_vars['content_width'] = 550;
		$theme_vars['gutter'] = 10;
		
		$theme_vars['page_width'] = $theme_vars['menu_width'] + $theme_vars['content_width'] + $theme_vars['gutter'];
		
		$theme_vars['max_image_width'] = $theme_vars['content_width'] - 20;
	}
	
	// Function:
	// theme_blogentry( $entry_array )
	//
	// Theme for Blog Entries
	// ----------------------
	// All data is stored the $entry_array associative array and
	// passed to the function. Keep in mind that multiple languages
	// are used. So, try not to hard-code 'english' strings. If
	// you are creating graphics for buttons, try to use icons
	// instead of words.
	//
	// (Please note, the "\n" at the end of the echo() command adds
	// a return charater in the HTML source. This is standard PHP
	// behavior. Note the '\n' will not work for this. It has to be
	// surrounded by double-quotes.)
	//
	// The array could contains the following keys:
	// $entry_array['subject']          = String: Subject line
	// $entry_array['date']             = String: Date posted in the appropriate language and format.
	// $entry_array['entry']            = String: The body of the blog entry
	// $entry_array['logged_in']       = Boolean: True if user is logged in (used to determine whether to show 'edit' and 'delete' buttons)
	// $entry_array['edit']['url']      = String: URL
	// $entry_array['edit']['name']     = String: The word 'edit' in the appropriate language.
	// $entry_array['delete']['url']    = String: URL
	// $entry_array['delete']['name']   = String: The word 'delete' in the appropriate language.
	// $entry_array['comment']['url']   = String: URL
	// $entry_array['comment']['name']  = String: This will be 'add comment', '1 comment', or '2 comments' in the appropriate language.
	// $entry_array['comment']['count'] = String: The number of 'views' in the appropriate language.
	// $entry_array['count']            = Integer: Index of current entry (i.e. use this if you want to add a line after every entry except the last one...)
	// $entry_array['maxcount']         = Integer: Total number of entries
	function theme_blogentry ( $entry_array ) {
		global $user_colors, $blog_theme, $theme_vars;
		
		$blog_content = '';
		$blog_content = $blog_content . '<div id="blog_date">' . $entry_array['date'] . '</div>';
		
		if ( isset( $entry_array['logged_in'] ) && $entry_array['logged_in'] == true ) {
			// Show 'edit' and 'delete' buttons if the user is logged-in...
			if ( isset( $entry_array['edit']['url'] ) ) {
				$blog_content = $blog_content . '<a href="' . $entry_array['edit']['url'] . '">[ ' . $entry_array['edit']['name'] . ' ]</a>';
			}
			if ( isset( $entry_array['delete']['url'] ) ) {
				$blog_content = $blog_content . '<a href="' . $entry_array['delete']['url'] . '">[ ' . $entry_array['delete']['name'] . ' ]</a><br /><br />';
			}
		}
		
		// Blog content body...
		$blog_content = $blog_content . $entry_array['entry'] . "\n";
		
		if ( isset( $entry_array['comment']['url'] ) ) {
			// Show 'add comment' button if set...
			$blog_content = $blog_content . '<br /><a href="' . $entry_array['comment']['url'] . '">[ ' . $entry_array['comment']['name'] . ' ]</a>' . "\n";
		}
		
		if ( isset( $entry_array['comment']['count'] ) ) {
			// Show '( x views )' string...
			$blog_content = $blog_content . ' ( ' . $entry_array['comment']['count'] . ' )' . "\n";
		}
		
		if ( isset( $entry_array['trackback']['url'] ) ) {
			// Show 'trackback' symbol
			$blog_content = $blog_content . '&nbsp;&nbsp;|&nbsp;&nbsp;<a href="' . $entry_array['trackback']['url'] . '">[ ' . $entry_array['trackback']['name'] . ' ]</a>' . "\n";;
		}
		
		if ( isset( $entry_array['permalink']['url'] ) ) {
			// Show 'permalink' symbol
			$blog_content = $blog_content . ' | <a href="' . $entry_array['permalink']['url'] . '">' . $entry_array['permalink']['name'] . '</a>';
		}
		
		if ( isset( $entry_array['stars'] ) ) {
			// Show 'permalink' symbol
			$blog_content = $blog_content . ' | ' . $entry_array['stars'];
		}
		
		$entry_html = rounded_box( $theme_vars['content_width'] - 10, '<div id="blog_title">' . $entry_array['subject'] . '</div>', $blog_content );
		
		return $entry_html;
	}
	
	function theme_staticentry ( $entry_array ) {
		$entry_html = theme_blogentry( $entry_array );
		return $entry_html;
	}
	
	function theme_commententry ( $entry_array ) {
		$entry_html = theme_blogentry( $entry_array );
		return $entry_html;
	}
	
	function theme_trackbackentry ( $entry_array ) {
		global $blog_config, $blog_theme, $user_colors, $theme_vars;
		
		$blog_content = '';
		
		if ( isset( $entry_array['logged_in'] ) && $entry_array['logged_in'] == true ) {
			// Show 'edit' and 'delete' buttons if the user is logged-in...
			if ( isset( $entry_array['delete']['url'] ) ) {
				$blog_content = $blog_content . '<a href="' . $entry_array['delete']['url'] . '">[ ' . $entry_array['delete']['name'] . ' ]</a><br /><br />';
			}
		}
		
		// Blog content body...
		$blog_content = $blog_content . $entry_array['excerpt'] . "<p>\n";

		if ( (isset( $entry_array['blog_name'] ) ) && ($entry_array['blog_name'] != "") ) {
		   $blog_content = $blog_content . '<a href="'.$entry_array["url"].'">[ ' . $entry_array["blog_name"] . " ]</a><p>\n";
		} else {
		   $blog_content = $blog_content . '<a href="'.$entry_array["url"].'">[ ' . $entry_array["url"] . " ]</a><p>\n";
		}
		
		$entry_html = rounded_box( $theme_vars['content_width'] - 10, '<div id="blog_title">' . $entry_array['title'] . '</div>', $blog_content );
		
		return $entry_html;
	}
	
	function rounded_box ( $box_width, $title_bar, $window_content ) {
		global $user_colors, $blog_theme;
		
		$img_path = 'themes/' . $blog_theme . '/images/box/';
		
		ob_start();
		// Begin Page Layout HTML
		?>
		<!-- ROUNDED BOX / <?php echo( $box_width ); ?>PX WIDE -->
		<table border="0" cellspacing="0" cellpadding="0" width="<?php echo( $box_width ); ?>">
			<tr>
				<td rowspan="2"><img src="<?php echo( $img_path ); ?>corner_tl.png" alt="" width="20" height="30" border="0"></td>
				<td width="<?php echo( $box_width - 40 ); ?>"><img src="<?php echo( $img_path ); ?>shadow_top.png" alt="" width="100%" height="10" border="0"></td>
				<td rowspan="2"><img src="<?php echo( $img_path ); ?>corner_tr.png" alt="" width="20" height="30" border="0"></td>
			</tr>
			<tr>
				<td style="height: 20px; background-repeat: repeat-x; background-position: 0px 0px; background-image: url(<?php echo( $img_path ); ?>bar.png); background-attachment: scroll;"><?php echo( $title_bar ); ?></td>
			</tr>
			<tr>
				<td><img src="<?php echo( $img_path ); ?>bar_shadow_left.png" alt="" width="20" height="10" border="0"></td>
				<td><img src="<?php echo( $img_path ); ?>bar_shadow.png" alt="" width="100%" height="10" border="0"></td>
				<td><img src="<?php echo( $img_path ); ?>bar_shadow_right.png" alt="" width="20" height="10" border="0"></td>
			</tr>
			<tr>
				<td background="<?php echo( $img_path ); ?>shadow_left.png"></td>
				<td bgcolor="#FFFFFF"><?php echo( $window_content ); ?></td>
				<td background="<?php echo( $img_path ); ?>shadow_right.png"></td>
			</tr>
			<tr>
				<td><img src="<?php echo( $img_path ); ?>corner_bl.png" alt="" width="20" height="20" border="0"></td>
				<td><img src="<?php echo( $img_path ); ?>shadow_bottom.png" alt="" width="100%" height="20" border="0"></td>
				<td><img src="<?php echo( $img_path ); ?>corner_br.png" alt="" width="20" height="20" border="0"></td>
			</tr>
		</table>
		<?php 
		// End Page Layout HTML
		$entry_html = ob_get_contents();
		ob_end_clean();
		
		return $entry_html;
	}
	
	// Function:
	// theme_default_colors( )
	//
	// Default Base Colors
	// -------------------
	// $user_colors is an associative array that stores
	// all color information. These are the default colors
	// for the theme. These values are read in, and then
	// get overwritten when the user saved colors are
	// read from file.
	//
	// Note
	// ----
	// You can create your own "keys" but they will not
	// show up in the "colors.php" document yet...
	//
	// Also, only these default keys have translations for
	// different languages. If something is missing, email
	// me and I'll add it for future releases.
	//
	// Eventually you'll have the option of disabling keys
	// and added keys will appear on the "color.php" page.
	function theme_default_colors () {
		global $lang_string;
		
		$color_def = array();
		
		// Backgrounds
		array_push( $color_def, array( 'id' => 'bg_color',
								'string' => $lang_string['bg_color'],
								'default' => 'D9D9D2' ) );
		
		// Borders
		array_push( $color_def, array( 'id' => 'inner_border_color',
								'string' => $lang_string['inner_border_color'],
								'default' => '9A9A8C' ) );
		array_push( $color_def, array( 'id' => 'header_txt_color',
								'string' => $lang_string['header_txt_color'],
								'default' => 'FFFFFF' ) );
		array_push( $color_def, array( 'id' => 'footer_txt_color',
								'string' => $lang_string['footer_txt_color'],
								'default' => 'FFFFFF' ) );
		array_push( $color_def, array( 'id' => 'txt_color',
								'string' => $lang_string['txt_color'],
								'default' => '737367' ) );
		array_push( $color_def, array( 'id' => 'headline_txt_color',
								'string' => $lang_string['headline_txt_color'],
								'default' => '737367' ) );
		array_push( $color_def, array( 'id' => 'date_txt_color',
								'string' => $lang_string['date_txt_color'],
								'default' => 'A6A695' ) );
		
								
		array_push( $color_def, array( 'id' => 'entry_title_text',
								'string' => $lang_string['entry_title_text'],
								'default' => '666661' ) );
		array_push( $color_def, array( 'id' => 'entry_text',
								'string' => $lang_string['entry_text'],
								'default' => '4F4F48' ) );
								
		array_push( $color_def, array( 'id' => 'menu_title_text',
								'string' => $lang_string['menu_title_text'],
								'default' => 'FFFFFF' ) );
		array_push( $color_def, array( 'id' => 'menu_text',
								'string' => $lang_string['menu_text'],
								'default' => 'FFFFFF' ) );
		
		array_push( $color_def, array( 'id' => 'link_reg_color',
								'string' => $lang_string['link_reg_color'],
								'default' => '59594F' ) );
		array_push( $color_def, array( 'id' => 'link_hi_color',
								'string' => $lang_string['link_hi_color'],
								'default' => 'FF6600' ) );
		array_push( $color_def, array( 'id' => 'link_down_color',
								'string' => $lang_string['link_down_color'],
								'default' => '6329F7' ) );
								
		array_push( $color_def, array( 'id' => 'menu_link_reg_color',
								'string' => $lang_string['menu_link_reg_color'],
								'default' => '59594F' ) );
		array_push( $color_def, array( 'id' => 'menu_link_hi_color',
								'string' => $lang_string['menu_link_hi_color'],
								'default' => 'FF6600' ) );
		array_push( $color_def, array( 'id' => 'menu_link_down_color',
								'string' => $lang_string['menu_link_down_color'],
								'default' => '6329F7' ) );
		
		return ( $color_def );
	}
	
	// Function:
	// theme_pagelayout( )
	//
	// Page Layout Container/Wrapper
	// -----------------------------
	// This function controls all HTML output to the browser.
	//
	// Invoking the page_content() fuction inserts the actual
	// contents of the page.
	//
	function theme_pagelayout () {
		global $user_colors, $blog_config, $blog_theme, $theme_vars;
		
		$img_path = 'themes/' . $blog_theme . '/images/';
		
		// Begin Page Layout HTML
		?>
		<body leftmargin="0" topmargin="0" marginheight="0" marginwidth="0">
			<br />
			<table border="0" width="<?php echo( $theme_vars['page_width'] ); ?>" cellspacing="0" cellpadding="0" align="center">
				<tr>
					<td>
						<!-- HEADER -->
						<img src="<?php echo( $img_path ); ?>header.png" alt="<?php echo($blog_config[ 'blog_title' ]); ?>" width="<?php echo( $theme_vars['page_width'] ); ?>" height="110" border="0">
					</td>
				</tr>
				<tr>
					<td>
						<!-- CONTENT -->
						<table border="0" width="<?php echo( $theme_vars['page_width'] ); ?>" cellspacing="0" cellpadding="0">
							<tr>
								<!-- TITLE BAR -->
								<td><img src="<?php echo( $img_path ); ?>shadow_left.png" alt="" width="10" height="20" border="0"></td>
								<td style="height: 20px;" background="<?php echo( $img_path ); ?>chrome_bar.png"><div id="header"><?php echo($blog_config[ 'blog_title' ]); ?></div></td>
								<td><img src="<?php echo( $img_path ); ?>shadow_right.png" alt="" width="10" height="20" border="0"></td>
							</tr>
							<tr>
								<!-- TITLE SHADOW -->
								<td><img src="<?php echo( $img_path ); ?>shadow_left.png" alt="" width="10" height="10" border="0"></td>
								<td><img src="<?php echo( $img_path ); ?>shadow_bar.png" alt="" width="<?php echo( $theme_vars['page_width'] - 20 ); ?>" height="10" border="0"></td>
								<td><img src="<?php echo( $img_path ); ?>shadow_right.png" alt="" width="10" height="10" border="0"></td>
							</tr>
							<tr>
								<!-- BLOG CONTENT -->
								<td background="<?php echo( $img_path ); ?>shadow_left.png"></td>
								<td background="<?php echo( $img_path ); ?>fill_background.png">
									<table width="<?php echo( $theme_vars['page_width'] - 20 ); ?>" border="0" cellspacing="0" cellpadding="0" align="left">
										<tr valign="top">
											<!-- MENU -->
											<td width="<?php echo( $theme_vars['menu_width'] - 10 ); ?>">
												<div id="menu">
													<?php theme_menu(); ?>
												</div>
											</td>
											<!-- GUTTER -->
											<td width="<?php echo( $theme_vars['gutter'] ); ?>">
												<img src="<?php echo( $img_path ); ?>spacer.gif" alt="" width="<?php echo( $theme_vars['gutter'] ); ?>" height="10" border="0">
											</td>
											<!-- ENTRIES -->
											<td width="<?php echo( $theme_vars['content_width'] - 10 ); ?>">
												<div id="maincontent">
													<?php page_content(); ?>
												</div>
											</td>
										</tr>
									</table>
								</td>
								<td background="<?php echo( $img_path ); ?>shadow_right.png"></td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<!-- FOOTER -->
						<img src="<?php echo( $img_path ); ?>bottom.png" alt="" width="<?php echo( $theme_vars['page_width'] ); ?>" height="30" border="0">
					</td>
				</tr>
				<tr>
					<td>
						<div id="footer"><?php echo($blog_config[ 'blog_footer' ]); ?> - <?php echo( page_generated_in() ); ?><br /><br /></div>
					</td>
				</tr>
			</table>
		</body>
		<?php 
		// End Page Layout HTML
	}
	
	// Function:
	// theme_popuplayout( )
	//
	// Popup Layout Container/Wrapper
	// -----------------------------
	// This function controls all HTML output to the browser.
	//
	// Same as above, but for the pop-up comment window and 
	// the image list pop-up.
	//
	function theme_popuplayout () {
		global $user_colors, $blog_config, $blog_theme, $theme_vars;
		
		$img_path = 'themes/' . $blog_theme . '/images/';
		
		// Begin Page Layout HTML
		?>
		<body leftmargin="0" topmargin="0" marginheight="0" marginwidth="0" background="<?php echo( $img_path ); ?>fill_background.png">
			<div id="popup_content">
				<?php page_content(); ?>
			</div>
		</body>
		<?php 
		// End Page Layout HTML
	}
	
	function theme_menu () {
		global $user_colors, $lang_string, $theme_vars, $logged_in, $sb_info;
		
		$result = menu_display_links();
		echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] . '<br />' . menu_display_login() ) );
		
		// DATOH_ADD
		$array = read_blocks($logged_in);
		for($i=0 ; $i<count($array) ; $i+=2) {
		    echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$array[$i].'</div>', $array[$i+1] ) );
		}
		// DATOH_END

		$result = menu_display_blognav();
		echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] ) );
		
		$result = menu_display_categories();
		echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] ) );
				
		// Search Box - Added in 0.3.7
		$result = menu_search_field();
		echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] ) );
		
		$result = menu_display_user();
		if ( $result['content'] != '' ) {
			echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] ) );
		}
		
		$result = menu_display_setup();
		if ( $result['content'] != '' ) {
			echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.$result['title'].'</div>', $result['content'] ) );
		}
		
		$result = menu_most_recent_comments();
		if ( $result['content'] != '' ) {
			echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.'Most Recent'.'</div>', $result['content'] ) );
		}
		
		$result = menu_most_recent_entries();
		if ( $result['content'] != '' ) {
			echo( rounded_box( $theme_vars['menu_width'] - 10, '<div id="title">'.'Most Recent'.'</div>', $result['content'] ) );
		}
	
		// Web Badges - Changed in 0.3.8
		echo( '<div align="center">' );
		echo( '<a href="http://sourceforge.net/projects/sphpblog/"><img style="margin-bottom: 5px;" src="interface/button_sphpblog.png" alt="Powered by Simple PHP Blog ' .  $sb_info[ 'version' ] . '" title="Powered by Simple PHP Blog ' .  $sb_info[ 'version' ] . '" border="0"></a><br />' );
		echo( '<a href="rss.php"><img style="margin-bottom: 5px;" src="interface/button_rss20.png" alt="Get RSS 2.0 Feed" title="Get RSS 2.0 Feed" border="0"></a><br />' );
		echo( '<a href="atom.php"><img style="margin-bottom: 5px;" src="interface/button_atom03.png" alt="Get Atom 0.3 Feed" title="Get Atom 0.3 Feed" border="0"></a><br />' );
		echo( '<a href="rdf.php"><img style="margin-bottom: 5px;" src="interface/button_rdf10.png" alt="Get RDF 1.0 Feed" title="Get RDF 1.0 Feed" border="0"></a><br />' );
		echo( '<a href="http://php.net/"><img style="margin-bottom: 5px;" src="interface/button_php.png" alt="Powered by PHP ' . phpversion() . '" title="Powered by PHP ' . phpversion() . '" border="0"></a><br />' );
		echo( '<img style="margin-bottom: 5px;" src="interface/button_txt.png" alt="Powered by Plain text files" title="Powered by Plain text files" border="0"><br />' );
		echo( '</div>' );
	}
	
?>